Takes a dataframe and replaces all the values in the
variable column with the value level. Columns
tracking which variable and level were used are also added to the dataframe.
build_one_level_df(dataframe, variable, level, one_variable_direction)a dataframe
The name of the column whose values we wish to change
The modified value to use in the variable column
A dataframe